@@ -19,6 +19,8 @@
 
 from pathlib import Path
 
+from pydantic import validate_arguments
+
 from renku.command.command_builder.command import Command
 from renku.domain_model.project_context import project_context
 
@@ -28,6 +30,7 @@ def mergetool_command():
     return Command().command(_mergetool).require_migration().with_database()
 
 
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
 def _mergetool(local: Path, remote: Path, base: Path) -> None:
     """Merge renku metadata files.
 
@@ -48,6 +51,7 @@ def mergetool_install_command():
     return Command().command(setup_mergetool)
 
 
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
 def setup_mergetool(with_attributes: bool = True):
     """Setup renku custom mergetool."""
     repository = project_context.repository
