@@ -140,7 +140,7 @@ class ActivityGraphViewModel:
 
         components = networkx.weakly_connected_components(self.graph)
         subgraphs = [self.graph.subgraph(component).copy() for component in components]
-        subgraphs = filter(lambda s: any(isinstance(n, Activity) for n in s), subgraphs)
+        subgraphs = list(filter(lambda s: any(isinstance(n, Activity) for n in s), subgraphs))
         subgraphs = sorted(subgraphs, key=self._subgraph_order_key)
 
         for subgraph in subgraphs:
