@@ -21,6 +21,7 @@ import json
 from datetime import datetime
 from typing import List, Optional
 
+from renku.core.config import get_value
 from renku.domain_model.project import Project
 from renku.domain_model.provenance.agent import Person
 
@@ -39,6 +40,7 @@ class ProjectViewModel:
         annotations: Optional[str],
         template_info: str,
         keywords: Optional[List[str]],
+        ssh_supported: bool = False,
     ):
         self.id = id
         self.name = name
@@ -52,6 +54,7 @@ class ProjectViewModel:
         self.template_info = template_info
         self.keywords = keywords
         self.keywords_str = ", ".join(keywords) if keywords else ""
+        self.ssh_supported = ssh_supported
 
     @classmethod
     def from_project(cls, project: Project):
@@ -88,4 +91,5 @@ class ProjectViewModel:
             else None,
             template_info=template_info,
             keywords=project.keywords,
+            ssh_supported=get_value("renku", "ssh_supported") == "true" or project.template_metadata.ssh_supported,
         )
