@@ -299,9 +299,9 @@ def get_upload_uri(dataset: Dataset, entity_path: Union[Path, str]) -> str:
 def move_files_to_dataset(dataset: Dataset, files: List[DatasetAddMetadata]):
     """Copy/Move files into a dataset's directory."""
 
-    def move_file(file: DatasetAddMetadata, storage: Optional[IStorage]):
+    def move_file(file: DatasetAddMetadata, storage: Optional[IStorage]) -> bool:
         if not file.has_action:
-            return
+            return False
 
         if file.action in (
             DatasetAddAction.COPY,
@@ -322,26 +322,33 @@ def move_files_to_dataset(dataset: Dataset, files: List[DatasetAddMetadata]):
             else:
                 file.action = DatasetAddAction.DOWNLOAD
 
-        if file.action == DatasetAddAction.COPY:
-            shutil.copy(file.source, file.destination)
-        elif file.action == DatasetAddAction.MOVE:
-            shutil.move(file.source, file.destination, copy_function=shutil.copy)  # type: ignore
-        elif file.action == DatasetAddAction.SYMLINK:
-            create_external_file(target=file.source, path=file.destination)
-            # NOTE: Don't track symlinks to external files in LFS
-            track_in_lfs = False
-        elif file.action == DatasetAddAction.DOWNLOAD:
-            assert file.provider, f"Storage provider isn't set for {file} with DOWNLOAD action"
-            storage = file.provider.get_storage()
-            storage.download(file.url, file.destination)
-        elif file.metadata_only:
-            # NOTE: Nothing to do when adding file to a dataset with a parent remote storage
-            pass
-        else:
-            raise errors.OperationError(f"Invalid action {file.action}")
+        file_to_upload = file.source.resolve()
 
-        if track_in_lfs and not dataset.storage:
-            track_paths_in_storage(file.destination)
+        try:
+            if file.action == DatasetAddAction.COPY:
+                shutil.copy(file.source, file.destination)
+            elif file.action == DatasetAddAction.MOVE:
+                shutil.move(file.source, file.destination, copy_function=shutil.copy)  # type: ignore
+            elif file.action == DatasetAddAction.SYMLINK:
+                create_external_file(target=file.source, path=file.destination)
+                # NOTE: Don't track symlinks to external files in LFS
+                track_in_lfs = False
+            elif file.action == DatasetAddAction.DOWNLOAD:
+                assert file.provider, f"Storage provider isn't set for {file} with DOWNLOAD action"
+                download_storage = file.provider.get_storage()
+                download_storage.download(file.url, file.destination)
+                file_to_upload = file.destination
+            elif file.metadata_only:
+                # NOTE: Nothing to do when adding file to a dataset with a parent remote storage
+                pass
+            else:
+                raise errors.OperationError(f"Invalid action {file.action}")
+        except OSError as e:
+            # NOTE: It's ok if copying data to a read-only mounted cloud storage fails
+            if "Read-only file system" in str(e) and storage:
+                pass
+            else:
+                raise
 
         # NOTE: We always copy the files to the dataset's data dir. If dataset has a storage backend, we also upload the
         # file to the remote storage.
@@ -352,19 +359,27 @@ def move_files_to_dataset(dataset: Dataset, files: List[DatasetAddMetadata]):
                 md5_hash = file.based_on.checksum
             else:
                 file_uri = get_upload_uri(dataset=dataset, entity_path=file.entity_path)
-                storage.upload(source=file.destination, uri=file_uri)
-                md5_hash = hash_file(file.destination, hash_type="md5") or ""
+                storage.upload(source=file_to_upload, uri=file_uri)
+                md5_hash = hash_file(file_to_upload, hash_type="md5") or ""
 
             file.based_on = RemoteEntity(url=file_uri, path=file.entity_path, checksum=md5_hash)
 
+        return track_in_lfs
+
     dataset_storage = None
     if dataset.storage:
         provider = ProviderFactory.get_storage_provider(uri=dataset.storage)
         dataset_storage = provider.get_storage()
 
+    lfs_files = []
+
     for dataset_file in files:
         # TODO: Parallelize copy/download/upload
-        move_file(file=dataset_file, storage=dataset_storage)
+        if move_file(file=dataset_file, storage=dataset_storage):
+            lfs_files.append(dataset_file.destination)
+
+    if lfs_files and not dataset.storage:
+        track_paths_in_storage(*lfs_files)
 
 
 def add_files_to_repository(dataset: Dataset, files: List[DatasetAddMetadata]):
@@ -391,8 +406,16 @@ def add_files_to_repository(dataset: Dataset, files: List[DatasetAddMetadata]):
 def update_dataset_metadata(dataset: Dataset, files: List[DatasetAddMetadata], clear_files_before: bool):
     """Add newly-added files to the dataset's metadata."""
     dataset_files = []
+    repo_paths: List[Union[Path, str]] = [
+        file.entity_path for file in files if (project_context.path / file.entity_path).exists()
+    ]
+
+    checksums = project_context.repository.get_object_hashes(repo_paths)
+
     for file in files:
-        dataset_file = DatasetFile.from_path(path=file.entity_path, source=file.url, based_on=file.based_on)
+        dataset_file = DatasetFile.from_path(
+            path=file.entity_path, source=file.url, based_on=file.based_on, checksum=checksums.get(file.entity_path)
+        )
         dataset_files.append(dataset_file)
 
     if clear_files_before:
