@@ -18,7 +18,7 @@
 """Renku exceptions."""
 
 from pathlib import Path
-from typing import List, Union
+from typing import List, Optional, Union
 
 import click
 from packaging.version import Version
@@ -84,9 +84,13 @@ class ParseError(RenkuException):
 class IncompatibleParametersError(ParameterError):
     """Raise in case of incompatible parameters/flags."""
 
-    def __init__(self, a: str = None, b: str = None):
+    def __init__(self, first_param: Optional[str] = None, second_param: Optional[str] = None):
         """Build a custom message."""
-        message = f"{a} is incompatible with {b}" if a is not None and b is not None else "Incompatible parameters"
+        message = (
+            f"{first_param} is incompatible with {second_param}"
+            if first_param is not None and second_param is not None
+            else "Incompatible parameters"
+        )
         super().__init__(message)
 
 
@@ -106,6 +110,10 @@ class AuthenticationError(RenkuException):
     """Raise when there is a problem with authentication."""
 
 
+class KeyNotFoundError(RenkuException):
+    """Raise when an SSH private or public key couldn't be found."""
+
+
 class DirtyRepository(RenkuException):
     """Raise when trying to work with dirty repository."""
 
@@ -522,6 +530,24 @@ class NodeNotFoundError(RenkuException):
         super(NodeNotFoundError, self).__init__(msg)
 
 
+class SSHNotFoundError(RenkuException):
+    """Raised when SSH client is not installed on the system."""
+
+    def __init__(self):
+        """Build a custom message."""
+        msg = "SSH client (ssh) could not be found on this system"
+        super(SSHNotFoundError, self).__init__(msg)
+
+
+class SSHNotSetupError(RenkuException):
+    """Raised when SSH client is not installed on the system."""
+
+    def __init__(self):
+        """Build a custom message."""
+        msg = "SSH is not set up correctly, use 'renku session ssh-setup' to set it up."
+        super(SSHNotSetupError, self).__init__(msg)
+
+
 class ObjectNotFoundError(RenkuException):
     """Raised when an object is not found in the storage."""
 
@@ -622,7 +648,7 @@ class ParameterLinkError(RenkuException):
 class GraphCycleError(RenkuException):
     """Raised when a parameter reference cannot be resolved to a parameter."""
 
-    def __init__(self, cycles: List[List[str]], message: str = None):
+    def __init__(self, cycles: List[List[str]], message: Optional[str] = None):
         """Embed exception and build a custom message."""
         if message:
             super().__init__(message)
@@ -652,6 +678,10 @@ class DockerError(RenkuException):
         super().__init__(f"Docker failed: {reason}")
 
 
+class DockerAPIError(DockerError):
+    """Raised when error has returned from the Docker API."""
+
+
 class SessionStartError(RenkuException):
     """Raised when an error occurs trying to start sessions."""
 
@@ -699,7 +729,7 @@ class MinimumVersionError(RenkuException):
 class DatasetProviderNotFound(DatasetException, ParameterError):
     """Raised when a dataset provider cannot be found based on a URI or a provider name."""
 
-    def __init__(self, *, name: str = None, uri: str = None, message: str = None):
+    def __init__(self, *, name: Optional[str] = None, uri: Optional[str] = None, message: Optional[str] = None):
         if message is None:
             if name:
                 message = f"Provider '{name}' not found"
@@ -725,7 +755,7 @@ class RCloneException(DatasetException):
 class StorageObjectNotFound(RCloneException):
     """Raised when a file or directory cannot be found in the remote storage."""
 
-    def __init__(self, error: str = None):
+    def __init__(self, error: Optional[str] = None):
         message = "Cannot find file/directory"
         if error:
             message = f"{message}: {error}"
