@@ -38,7 +38,7 @@ class IPlanGateway(ABC):
         """Get a plan by name or id."""
         raise NotImplementedError()
 
-    def list_by_name(self, starts_with: str, ends_with: str = None) -> List[str]:
+    def list_by_name(self, starts_with: str, ends_with: Optional[str] = None) -> List[str]:
         """Search plans by name."""
         raise NotImplementedError
 
