@@ -24,7 +24,7 @@ import shutil
 import tempfile
 from enum import Enum, IntEnum, auto
 from pathlib import Path
-from typing import Any, Dict, List, Optional, Tuple, cast
+from typing import Any, Dict, List, Optional, Tuple
 
 from packaging.version import Version
 
@@ -132,6 +132,7 @@ def copy_template_to_project(
             template_version=rendered_template.template.version,
             immutable_template_files=rendered_template.template.immutable_files.copy(),
             metadata=json.dumps(rendered_template.metadata),
+            ssh_supported=rendered_template.template.ssh_supported,
         )
 
     actions_mapping: Dict[FileAction, Tuple[str, str]] = {
@@ -183,6 +184,8 @@ def get_file_actions(
     rendered_template: RenderedTemplate, template_action: TemplateAction, interactive
 ) -> Dict[str, FileAction]:
     """Render a template regarding files in a project."""
+    from renku.core.template.usecase import is_dockerfile_updated_by_user
+
     if interactive and not communication.has_prompt():
         raise errors.ParameterError("Cannot use interactive mode with no prompt")
 
@@ -219,6 +222,8 @@ def get_file_actions(
         elif interactive:
             overwrite = communication.confirm(f"Overwrite {relative_path}?", default=True)
             return FileAction.OVERWRITE if overwrite else FileAction.KEEP
+        elif relative_path == "Dockerfile" and not is_dockerfile_updated_by_user():
+            return FileAction.OVERWRITE
         elif should_keep(relative_path):
             return FileAction.KEEP
         else:
@@ -247,6 +252,8 @@ def get_file_actions(
                 return FileAction.OVERWRITE if overwrite else FileAction.KEEP
         elif not remote_changes:
             return FileAction.IGNORE_UNCHANGED_REMOTE
+        elif relative_path == "Dockerfile" and not is_dockerfile_updated_by_user():
+            return FileAction.OVERWRITE
         elif file_deleted or local_changes:
             if relative_path in immutable_files:
                 # NOTE: There are local changes in a file that should not be changed by users, and the file was
@@ -416,6 +423,9 @@ class RepositoryTemplates(TemplatesSource):
 
     A template repository is checked out at a specific Git reference if one is provided. However, it's still possible to
     get available versions of templates.
+
+    For these templates, ``reference`` is set to whatever user passed as a reference (defaults to remote HEAD if not
+    passed) and ``version`` is set to the commit SHA of the reference commit.
     """
 
     def __init__(self, path, source, reference, version, repository: Repository, skip_validation: bool = False):
@@ -482,10 +492,7 @@ class RepositoryTemplates(TemplatesSource):
         """Return if template id is available at a reference."""
         try:
             content = self.repository.get_content(TEMPLATE_MANIFEST, revision=reference)
-
-            if isinstance(content, bytes):
-                return False
-            manifest = TemplatesManifest.from_string(cast(str, content))
+            manifest = TemplatesManifest.from_string(content)
         except (errors.FileNotFound, errors.InvalidTemplateError):
             return False
         else:
