@@ -32,6 +32,7 @@ from typing import TYPE_CHECKING, Dict, List, Optional, Set, Tuple, Union, cast
 from uuid import uuid4
 
 from renku.core import errors
+from renku.infrastructure.repository import DiffChangeType
 
 if TYPE_CHECKING:
     from renku.domain_model.entity import Collection, Entity
@@ -39,7 +40,6 @@ if TYPE_CHECKING:
     from renku.domain_model.provenance.agent import Person, SoftwareAgent
     from renku.infrastructure.repository import Commit, Remote, Repository
 
-
 COMMIT_DIFF_STRATEGY = "DIFF"
 STARTED_AT = int(time.time() * 1e3)
 
@@ -196,7 +196,6 @@ def get_renku_repo_url(remote_url, deployment_hostname=None, access_token=None):
         remote_url: The repository URL.
         deployment_hostname: The host name used by this deployment (Default value = None).
         access_token: The OAuth2 access token (Default value = None).
-
     Returns:
         The Renku repository URL with credentials.
     """
@@ -204,7 +203,8 @@ def get_renku_repo_url(remote_url, deployment_hostname=None, access_token=None):
     path = parsed_remote.path.strip("/")
     if path.startswith("gitlab/"):
         path = path.replace("gitlab/", "")
-    path = posixpath.join(CLI_GITLAB_ENDPOINT, path)
+    if not path.startswith(f"{CLI_GITLAB_ENDPOINT}/"):
+        path = posixpath.join(CLI_GITLAB_ENDPOINT, path)
 
     credentials = f"renku:{access_token}@" if access_token else ""
     hostname = deployment_hostname or parsed_remote.hostname
@@ -241,6 +241,12 @@ def create_backup_remote(repository: "Repository", remote_name: str, url: str) -
         return backup_remote_name, False, remote
 
 
+def set_git_credential_helper(repository: "Repository", hostname):
+    """Set up credential helper for renku git."""
+    with repository.get_configuration(writable=True) as config:
+        config.set_value("credential", "helper", f"!renku credentials --hostname {hostname}")
+
+
 def get_full_repository_path(url: Optional[str]) -> str:
     """Extract hostname/path of a git repository from its URL.
 
@@ -250,7 +256,7 @@ def get_full_repository_path(url: Optional[str]) -> str:
     Returns:
         The hostname plus path extracted from the URL.
     """
-    if str is None:
+    if url is None:
         return ""
 
     parsed_url = parse_git_url(url)
@@ -365,7 +371,11 @@ def is_path_safe(path: Union[Path, str]) -> bool:
 
 
 def get_entity_from_revision(
-    repository: "Repository", path: Union[Path, str], revision: Optional[str] = None, bypass_cache: bool = False
+    repository: "Repository",
+    path: Union[Path, str],
+    revision: Optional[str] = None,
+    bypass_cache: bool = False,
+    checksum: Optional[str] = None,
 ) -> "Entity":
     """Return an Entity instance from given path and revision.
 
@@ -374,12 +384,12 @@ def get_entity_from_revision(
         path(Union[Path, str]): The path of the entity.
         revision(str, optional): The revision to check at (Default value = None).
         bypass_cache(bool): Whether to ignore cached entries and get information from disk (Default value = False).
-
+        checksum(str, optional): Pre-calculated checksum for performance reasons, will be calculated if not set.
     Returns:
         Entity: The Entity for the given path and revision.
 
     """
-    from renku.domain_model.entity import Collection, Entity
+    from renku.domain_model.entity import NON_EXISTING_ENTITY_CHECKSUM, Collection, Entity
 
     def get_directory_members(absolute_path: Path) -> List[Entity]:
         """Return first-level files/directories in a directory."""
@@ -407,10 +417,13 @@ def get_entity_from_revision(
         return cached_entry
 
     # NOTE: For untracked directory the hash is None; make sure to stage them first before calling this function.
-    checksum = repository.get_object_hash(revision=revision, path=path)
+    if not checksum:
+        checksum = repository.get_object_hash(revision=revision, path=path)
     # NOTE: If object was not found at a revision it's either removed or exists in a different revision; keep the
     # entity and use revision as checksum
-    checksum = checksum or revision or "HEAD"
+    if isinstance(revision, str) and revision == "HEAD":
+        revision = repository.head.commit.hexsha
+    checksum = checksum or revision or NON_EXISTING_ENTITY_CHECKSUM
     id = Entity.generate_id(checksum=checksum, path=path)
 
     absolute_path = repository.path / path
@@ -675,6 +688,9 @@ def clone_renku_repository(
 
     if create_backup:
         create_backup_remote(repository=repository, remote_name="origin", url=url)
+        set_git_credential_helper(
+            repository=cast("Repository", repository), hostname=deployment_hostname or parsed_url.hostname
+        )
 
     return repository
 
@@ -1094,7 +1110,7 @@ def finalize_commit(
     if isinstance(commit_only, list):
         for path_ in commit_only:
             p = repository.path / path_
-            if p.exists() or change_types.get(str(path_)) == "D":
+            if p.exists() or change_types.get(str(path_)) == DiffChangeType.DELETED:
                 repository.add(path_)
 
     if not commit_only:
