@@ -21,7 +21,6 @@ import fnmatch
 import os
 import re
 import tempfile
-from collections.abc import Iterable
 from pathlib import Path
 from typing import TYPE_CHECKING, List, Optional, Tuple, Union
 
@@ -30,6 +29,7 @@ from packaging.version import Version
 from renku.core import errors
 from renku.core.config import get_value, set_value
 from renku.core.constant import RENKU_HOME, RENKU_PROTECTED_PATHS, RENKU_TMP
+from renku.core.migration.utils import OLD_METADATA_PATH
 from renku.core.util import communication
 from renku.core.util.os import is_subpath
 
@@ -42,9 +42,6 @@ def construct_creators(creators: List[Union[dict, str]], ignore_email=False) ->
     """Parse input and return a list of Person."""
     creators = creators or []
 
-    if not isinstance(creators, Iterable) or isinstance(creators, str):
-        raise errors.ParameterError("Invalid creators type")
-
     people = []
     no_email_warnings = []
     for creator in creators:
@@ -101,25 +98,34 @@ def is_external_file(path: Union[Path, str], project_path: Path):
     return str(os.path.join(RENKU_HOME, POINTERS)) in pointer
 
 
-def read_renku_version_from_dockerfile(path: Optional[Union[Path, str]] = None) -> Optional[str]:
+def read_renku_version_from_dockerfile(path: Optional[Union[Path, str]] = None) -> Optional[Version]:
     """Read RENKU_VERSION from the content of path if a valid version is available."""
     from renku.domain_model.project_context import project_context
 
-    path = Path(path) if path else project_context.docker_path
+    path = Path(path) if path else project_context.dockerfile_path
     if not path.exists():
         return None
 
-    docker_content = path.read_text()
-    m = re.search(r"^\s*ARG RENKU_VERSION=(.+)$", docker_content, flags=re.MULTILINE)
+    m = re.search(r"^\s*ARG RENKU_VERSION=(\d+\.\d+\.\d+\S*)$", path.read_text(), flags=re.MULTILINE)
     if not m:
         return None
 
     try:
-        return str(Version(m.group(1)))
+        return Version(m.group(1))
     except ValueError:
         return None
 
 
+def replace_renku_version_in_dockerfile(dockerfile_content: str, version: str) -> str:
+    """Replace Renku version in the Dockerfile."""
+    return re.sub(
+        r"^\s*ARG RENKU_VERSION=(\d+\.\d+\.\d+\S*)$",
+        f"ARG RENKU_VERSION={version}",
+        dockerfile_content,
+        flags=re.MULTILINE,
+    )
+
+
 def make_project_temp_dir(project_path: Path) -> Path:
     """Create a temporary directory inside project's temp path."""
     base = project_path / RENKU_HOME / RENKU_TMP
@@ -184,3 +190,13 @@ def is_protected_path(path: Path) -> bool:
             return True
 
     return False
+
+
+def is_renku_project() -> bool:
+    """Check if repository is a renku project."""
+    from renku.domain_model.project_context import project_context
+
+    try:
+        return project_context.project is not None
+    except ValueError:  # NOTE: Error in loading due to an older schema
+        return project_context.metadata_path.joinpath(OLD_METADATA_PATH).exists()
