@@ -20,6 +20,7 @@
 import fnmatch
 import glob
 import hashlib
+import io
 import os
 import re
 import shutil
@@ -38,7 +39,9 @@ def get_relative_path_to_cwd(path: Union[Path, str]) -> str:
     return os.path.relpath(absolute_path, os.getcwd())
 
 
-def get_absolute_path(path: Union[Path, str], base: Union[Path, str] = None, resolve_symlinks: bool = False) -> str:
+def get_absolute_path(
+    path: Union[Path, str], base: Optional[Union[Path, str]] = None, resolve_symlinks: bool = False
+) -> str:
     """Return absolute normalized path."""
     if base is not None:
         base = Path(base).resolve() if resolve_symlinks else os.path.abspath(base)
@@ -246,12 +249,20 @@ def hash_file(path: Union[Path, str], hash_type: str = "sha256") -> Optional[str
         return hash_file_descriptor(f, hash_type)
 
 
+def hash_string(content: str, hash_type: str = "sha256") -> str:
+    """Hash a string."""
+    content_bytes = content.encode("utf-8")
+    file = io.BytesIO(content_bytes)
+
+    return hash_file_descriptor(file, hash_type)
+
+
 def hash_file_descriptor(file: BinaryIO, hash_type: str = "sha256") -> str:
     """Hash content of a file descriptor."""
     hash_type = hash_type.lower()
     assert hash_type in ("sha256", "md5")
 
-    hash_value = hashlib.sha256() if hash_type == "sha256" else hashlib.md5()
+    hash_value = hashlib.sha256() if hash_type == "sha256" else hashlib.md5()  # nosec
 
     for byte_block in iter(lambda: file.read(BLOCK_SIZE), b""):
         hash_value.update(byte_block)
