@@ -168,12 +168,12 @@ class Step:
         command: str,
         date_created: Optional[datetime] = None,
         description: Optional[str] = None,
-        inputs: List[Input] = None,
+        inputs: Optional[List[Input]] = None,
         keywords: Optional[List[str]] = None,
         name: str,
         original_command: Optional[str] = None,
-        outputs: List[Output] = None,
-        parameters: List[Parameter] = None,
+        outputs: Optional[List[Output]] = None,
+        parameters: Optional[List[Parameter]] = None,
         path: Union[Path, str],
         success_codes: Optional[List[int]] = None,
         workflow_file_name: str,
@@ -275,6 +275,7 @@ class Parameter(BaseParameter):
             description=self.description,
             id=CommandParameter.generate_id(plan_id=plan_id, name=self.name, postfix=postfix),
             name=self.name,
+            name_set_by_user=self.name_set_by_user,
             position=self.position,
             postfix=postfix,
             prefix=self.prefix,
@@ -312,6 +313,7 @@ class Input(BasePath):
             id=CommandInput.generate_id(plan_id=plan_id, name=self.name, postfix=postfix),
             mapped_to=MappedIOStream.from_str(self.mapped_to) if self.mapped_to else None,
             name=self.name,
+            name_set_by_user=self.name_set_by_user,
             position=self.position,
             postfix=postfix,
             prefix=self.prefix,
@@ -336,6 +338,7 @@ class Output(BasePath):
             id=CommandOutput.generate_id(plan_id=plan_id, name=self.name, postfix=postfix),
             mapped_to=MappedIOStream.from_str(self.mapped_to) if self.mapped_to else None,
             name=self.name,
+            name_set_by_user=self.name_set_by_user,
             position=self.position,
             postfix=postfix,
             prefix=self.prefix,
