@@ -16,6 +16,3 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Model objects used in Python SDK."""
-from .datastructures import Collection, Model
-
-__all__ = ("Collection", "Model")
