@@ -135,6 +135,7 @@ class TemplatesManifest:
                     description=cast(str, t.get("description")),
                     parameters=cast(Dict[str, Dict[str, Any]], t.get("variables") or t.get("parameters")),
                     icon=cast(str, t.get("icon")),
+                    ssh_supported=t.get("ssh_supported", False),
                     immutable_files=t.get("immutable_template_files", []),
                     allow_update=t.get("allow_template_update", True),
                     source=None,
@@ -208,6 +209,7 @@ class Template:
         description: str,
         parameters: Dict[str, Dict[str, Any]],
         icon: str,
+        ssh_supported: bool,
         immutable_files: List[str],
         allow_update: bool,
         source: Optional[str],
@@ -224,6 +226,7 @@ class Template:
         self.name: str = name
         self.description: str = description
         self.icon = icon
+        self.ssh_supported = ssh_supported
         self.immutable_files: List[str] = immutable_files or []
         self.allow_update: bool = allow_update
         parameters = parameters or {}
@@ -433,7 +436,9 @@ class TemplateParameter:
             issues.append(issue)
 
         if self.possible_values and not isinstance(self.possible_values, list):
-            issue = f"Invalid type for possible values of template variable '{self.name}': '{self.possible_values}'"
+            issue = (  # type: ignore[unreachable]
+                "Invalid type for possible values of template variable " f"'{self.name}': '{self.possible_values}'"
+            )
             if raise_errors:
                 raise errors.InvalidTemplateError(issue)
             issues.append(issue)
@@ -529,7 +534,7 @@ class TemplateMetadata:
         # NOTE: Always set __renku_version__ to the value read from the Dockerfile (if available) since setting/updating
         # the template doesn't change project's metadata version and shouldn't update the Renku version either
         renku_version = metadata.get("__renku_version__")
-        metadata["__renku_version__"] = read_renku_version_from_dockerfile() or renku_version or __version__
+        metadata["__renku_version__"] = str(read_renku_version_from_dockerfile()) or renku_version or __version__
 
         return cls(metadata=metadata, immutable_files=immutable_files)
 
