@@ -21,20 +21,21 @@ from flask import request
 from renku.ui.service.config import SERVICE_PREFIX
 from renku.ui.service.controllers.templates_create_project import TemplatesCreateProjectCtrl
 from renku.ui.service.controllers.templates_read_manifest import TemplatesReadManifestCtrl
-from renku.ui.service.views.api_versions import ALL_VERSIONS, VersionedBlueprint
+from renku.ui.service.views.api_versions import ALL_VERSIONS, V2_0, VersionedBlueprint
 from renku.ui.service.views.decorators import accepts_json, requires_cache, requires_identity
 from renku.ui.service.views.error_handlers import (
     handle_common_except,
     handle_templates_create_errors,
     handle_templates_read_errors,
 )
+from renku.ui.service.views.v1.templates import add_v1_specific_endpoints
 
 TEMPLATES_BLUEPRINT_TAG = "templates"
 templates_blueprint = VersionedBlueprint(TEMPLATES_BLUEPRINT_TAG, __name__, url_prefix=SERVICE_PREFIX)
 
 
 @templates_blueprint.route(
-    "/templates.read_manifest", methods=["GET"], provide_automatic_options=False, versions=ALL_VERSIONS
+    "/templates.read_manifest", methods=["GET"], provide_automatic_options=False, versions=[V2_0]
 )
 @handle_common_except
 @handle_templates_read_errors
@@ -102,3 +103,6 @@ def create_project_from_template(user_data, cache):
         - templates
     """
     return TemplatesCreateProjectCtrl(cache, user_data, dict(request.json)).to_response()  # type: ignore
+
+
+templates_blueprint = add_v1_specific_endpoints(templates_blueprint)
